@@ -9,13 +9,8 @@
 #' @importFrom graphics plot
 #' @S3method plot TestResult
 plot.TestResult <- function(x, ...) {
-
-  ## Make codetools (R CMD check) happy:
-  value <- tests <- datasets <- samples <- NULL
-
-
   p <- ggplot(x, aes(samples, value))
-  p <- p + facet_grid(tests ~ datasets, scale = "free_y")
+  p <- p + facet_grid(tests ~ datasets, scales = "free_y")
   p <- p + geom_line()
 
   p
